@@ -41,26 +41,23 @@ class BaseCacheMixin:
             self._memory_cache = value
 
     @log
-    def _flush_self_cache(self):
-        """Delete cache for only current service point"""
+    def flush_cache(self):
+        """Delete cache for current endpoint"""
         self._memory_cache = None
         data = cache.get(self._cache_key)
         if data:
             data.pop(self._data_key, False)
             cache.set(self._cache_key, data, self._cache_period)
 
-    def flush_cache(self):
-        """Flush cache for self and related points"""
-        self._flush_self_cache()
+    def _get_related_points(self) -> list:
+        """Set related points here"""
+        return list()
+
+    def _flush_cache_related_points(self):
         related_points = self._get_related_points()
         for point in related_points:
             point.flush_cache()
 
-    @staticmethod
-    def _get_related_points() -> list:
-        """Set related points here"""
-        return list()
-
 
 class CacheMixin(BaseCacheMixin):
 
@@ -77,11 +74,11 @@ class CacheMixin(BaseCacheMixin):
     def _post(self, payload: dict):
         self._payload = payload
         super()._post(payload)
-        self.flush_cache()
+        self._flush_cache_related_points()
 
     def _post_file(self, file, file_name, type_):
         super()._post_file(file, file_name, type_)
-        self.flush_cache()
+        self._flush_cache_related_points()
 
 
 class CacheObjectMixin(BaseCacheMixin):
@@ -99,7 +96,7 @@ class CacheObjectMixin(BaseCacheMixin):
     def _put(self, payload: dict):
         self._payload = payload
         super()._put(payload)
-        self.flush_cache()
+        self._flush_cache_related_points()
 
     @property
     def _data_key(self):
