@@ -74,11 +74,6 @@ class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
         objects = self.open_loans()
         return objects[-1] if len(objects) > 0 else None
 
-    def _get_related_points(self) -> list:
-        related_points = super()._get_related_points()
-        related_points.append(LoanPaginationNonePoint(self._user))
-        return related_points
-
 
 class LoanPaginationNonePoint(ListPointMixin, ContractPoint):
     _point_id = loans_loans_loan_pagination_none
