@@ -1,12 +1,12 @@
-__all__ = ()
+__all__ = ('RussianIdentificationProcessPoint',)
 
 from expressmoney.api import *
 from expressmoney.viewflow import status
 
-SERVICE_NAME = 'profiles'
+SERVICE = 'profiles'
 
 
-class RussiaReadContract(Contract):
+class RussianIdentificationProcessReadContract(Contract):
     EMPTY = status.EMPTY
     IN_PROCESS = status.IN_PROCESS
     SUCCESS = status.SUCCESS
@@ -15,16 +15,17 @@ class RussiaReadContract(Contract):
     RETRY = status.RETRY
 
     AUTO_RESULT_CHOICES = (
-        (IN_PROCESS, ' In process'),
-        (SUCCESS, 'Success'),
-        (ERROR, 'Error'),
-        (FAILURE, 'Failure'),
+        (IN_PROCESS, IN_PROCESS),
+        (SUCCESS, SUCCESS),
+        (ERROR, ERROR),
+        (FAILURE, FAILURE),
     )
 
     MANUAL_RESULT_CHOICES = (
-        (SUCCESS, 'Success'),
-        (RETRY, 'Retry'),
-        (FAILURE, 'Failure'),
+        (EMPTY, EMPTY),
+        (SUCCESS, SUCCESS),
+        (RETRY, RETRY),
+        (FAILURE, FAILURE),
     )
     pagination = PaginationContract()
     id = serializers.IntegerField(min_value=1)
@@ -48,9 +49,10 @@ class RussiaReadContract(Contract):
     passport_number_old = serializers.CharField(max_length=6, allow_blank=True)
 
 
-profiles_identification_russia = ID(SERVICE_NAME, 'identification', 'russia')
+viewsets = 'russian_identification_process'
+profiles_identification_russian_identification_process = ID(SERVICE, 'identification', viewsets)
 
 
-class RussiaPoint(ListPointMixin, ContractPoint):
-    _point_id = profiles_identification_russia
-    _read_contract = RussiaReadContract
+class RussianIdentificationProcessPoint(ListPointMixin, ContractPoint):
+    _point_id = profiles_identification_russian_identification_process
+    _read_contract = RussianIdentificationProcessReadContract
