@@ -66,46 +66,32 @@ class ProfileReadContract(ProfileCreateContract):
     address_coordinates = serializers.CharField(max_length=64, allow_blank=True)
 
 
-class RussianProfileUpdateContractMixin:
-    # Russian fields
+class RussianProfileUpdateContract(ProfileUpdateContract):
     passport_serial = serializers.CharField(max_length=4)
     passport_number = serializers.CharField(max_length=6)
 
 
-class RussianProfileCreateContractMixin:
-    # Russian fields
+class RussianProfileCreateContract(ProfileCreateContract):
+    passport_serial = serializers.CharField(max_length=4)
+    passport_number = serializers.CharField(max_length=6)
     passport_issue_name = serializers.CharField(max_length=256, allow_blank=True)
     passport_code = serializers.CharField(max_length=16)
     passport_date = serializers.DateField()
     income = serializers.IntegerField(allow_null=True)
 
 
-class RussianProfileReadContractMixin:
-    # Russian fields
+class RussianProfileReadContract(ProfileReadContract,):
+    passport_serial = serializers.CharField(max_length=4)
+    passport_number = serializers.CharField(max_length=6)
+    passport_issue_name = serializers.CharField(max_length=256, allow_blank=True)
+    passport_code = serializers.CharField(max_length=16)
+    passport_date = serializers.DateField()
+    income = serializers.IntegerField(allow_null=True)
     income_region = serializers.IntegerField(allow_null=True)
     court_address = serializers.CharField(max_length=256, allow_blank=True)
     fias_region = serializers.CharField(max_length=256, allow_blank=True)
 
 
-class RussianProfileUpdateContract(RussianProfileUpdateContractMixin, ProfileUpdateContract):
-    pass
-
-
-class RussianProfileCreateContract(RussianProfileUpdateContractMixin,
-                                   RussianProfileCreateContractMixin,
-                                   ProfileCreateContract
-                                   ):
-    pass
-
-
-class RussianProfileReadContract(RussianProfileUpdateContractMixin,
-                                 RussianProfileCreateContractMixin,
-                                 RussianProfileReadContractMixin,
-                                 ProfileReadContract,
-                                 ):
-    pass
-
-
 profiles_profiles_russian_profile = ID(SERVICE_NAME, 'profiles', 'russian_profile')
 profiles_profiles_user_profile = ID(SERVICE_NAME, 'profiles', 'user_profile')
 
